pub struct UpgradeableClient<'a> {
pub env: Env,
pub address: Address,
/* private fields */
}Expand description
UpgradeableClient is a client for calling the contract defined in “Upgradeable”.
Fields
env: Envaddress: AddressImplementations
Sourceimpl<'a> UpgradeableClient<'a>
impl<'a> UpgradeableClient<'a>
Sourcepub fn upgrade(&self, new_wasm_hash: &BytesN<32>, operator: &Address)
pub fn upgrade(&self, new_wasm_hash: &BytesN<32>, operator: &Address)
Upgrades the contract by setting a new WASM bytecode. The contract will only be upgraded after the invocation has successfully completed.
Arguments
e- Access to Soroban environment.new_wasm_hash- A 32-byte hash identifying the new WASM blob, uploaded to the ledger.operator- The authorized address performing the upgrade.
Sourcepub fn try_upgrade(
&self,
new_wasm_hash: &BytesN<32>,
operator: &Address,
) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
pub fn try_upgrade( &self, new_wasm_hash: &BytesN<32>, operator: &Address, ) -> Result<Result<(), <() as TryFromVal<Env, Val>>::Error>, Result<Error, InvokeError>>
Upgrades the contract by setting a new WASM bytecode. The contract will only be upgraded after the invocation has successfully completed.
Arguments
e- Access to Soroban environment.new_wasm_hash- A 32-byte hash identifying the new WASM blob, uploaded to the ledger.operator- The authorized address performing the upgrade.