UpgradeableInternal

Trait UpgradeableInternal 

pub trait UpgradeableInternal {
    // Required method
    fn _require_auth(e: &Env, operator: &Address);
}
Trait to be implemented for a custom upgrade authorization mechanism. Requires defining access control logic for who can upgrade the contract.

Required Methods

fn _require_auth(e: &Env, operator: &Address)

Ensures the operator has signed and is authorized to perform the upgrade.

This must be implemented by the consuming contract.

Arguments
  • e - The Soroban environment.
  • operator - The address attempting the upgrade. Can be G-account, or another contract (C-account) such as timelock or governor.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors